@@ -18,7 +18,7 @@ class BaseModel(metaclass=MetaBase):
             try:
                 if _type and _v is not None and not isinstance(_v, _type):
                     _v = PermissionEnum[_v].value \
-                        if _k in ("origin","current") else _type(*_v) if _k == "messageChain" else _type(**_v)
+                        if _k in ("origin", "current") else _type(*_v) if _k == "messageChain" else _type(**_v)
             except:
                 print(_k, ":", _v, "=>", _type)
                 print(self.__annotations__)
@@ -28,8 +28,10 @@ class BaseModel(metaclass=MetaBase):
     @classmethod
     def parse(cls, *args, **kwargs) -> "BaseModel":
         _params = [(_K, _V) for _K, _V in kwargs.items()]
-        _arg_mapper = filter(lambda x: x if x[0] in kwargs.keys() and x[0] != "type" else None, _params)
-        _filted = {_K: _V for _K, _V in filter(lambda x: x is not None, _arg_mapper)}
+        _arg_mapper = filter(lambda x: x if x[0] in kwargs.keys(
+        ) and x[0] != "type" else None, _params)
+        _filted = {_K: _V for _K, _V in filter(
+            lambda x: x is not None, _arg_mapper)}
         _obj = cls(**_filted)
         return _obj
 
