@@ -8,7 +8,7 @@ from functools import wraps
 from karas.Sender import ReceptorBase
 
 
-def error_throw(func:Awaitable):
+def error_throw(func: Awaitable):
     @wraps(func)
     async def _wrapper(*args, **kwargs):
         try:
@@ -16,15 +16,14 @@ def error_throw(func:Awaitable):
                 _response = await func(*args, **kwargs)
             else:
                 _response = func(*args, **kwargs)
-        except RuntimeError as _re:
-            raise
         except Exception as e:
-            _,_,tb = sys.exc_info()
-            traceback.print_tb(tb,limit=10)
+            # _,_,tb = sys.exc_info()
+            # traceback.print_tb(tb,limit=10)
+            raise
         else:
             return _response
     return _wrapper
-    
+
 
 def echo_receiver(ws: aiohttp.ClientWebSocketResponse, _return: str = None):
     def wrapper(func):
@@ -53,7 +52,8 @@ def wrap_data_json(
         dict: _description_
     """
     if content is not None:
-        content = {_K:_V.id if isinstance(_V,ReceptorBase) else _V for _K,_V in content.items()}
+        content = {_K: _V.id if isinstance(
+            _V, ReceptorBase) else _V for _K, _V in content.items()}
     return {
         "syncId": syncId,
         "command": command,
